Bonjour,

J'apprécie OpenFisca mais j'ai rencontré un problème.

### Voici ce que j'ai fait :


### Voici que j'attendais qu'il se produise :


### Voici ce qui s'est effectivement produit :


### Voici les données (ou un lien vers celle-ci) qui permettent de reproduire le problème :



## Éléments de contexte

Je me reconnais principalement en tant que :

- Économiste _(Je fais des simulations sur des données d'enquêtes ou administratives)_.
- Expert _(Je modélise la législation et je crée des tests)_.
- Journaliste/commentateur _(Je crée des visualisations)_.
- Développeur _(Je crée des outils utilisant OpenFisca)_.
- Historien _(Je suis intéressé par l'historique de la législation)_.
- Lobbyiste _(Je modélise des réformes pour les promouvoirs)_.
- Producteur _(Je réalise des calculs sur des situations individuelles)_.

(Effacer les lignes ne correspondant pas à votre situation)
